@@ -3,6 +3,7 @@
 TDMS File Format Internal Structure
 http://www.ni.com/product-documentation/5696/en/
 """
+import re
 import math
 import struct
 from datetime import datetime, timedelta, timezone
@@ -87,6 +88,8 @@ STRUCT_FORMAT = {
     TdsDataType.DAQmxRawData: (4, "i"),
 }
 
+VALIDIDENTIFIER = "^[a-zA-Z][a-zA-Z0-9_]*$"
+
 
 class TdmsObject:
     """Base class for the three TDMS object types: File, Group and Channel
@@ -145,6 +148,15 @@ class TdmsObject:
         attributes = [key for key in self.__dict__ if not key.startswith("_")]
         return len(attributes)
 
+    def __dir__(self):
+        attrs = []
+        for attr in filter(lambda s: not s.startswith("_"), super().__dir__()):
+            if re.match(VALIDIDENTIFIER, attr) is not None:
+                attrs.append(attr)
+            else:
+                attrs.append(f'["{attr}"]')
+        return attrs
+
     @staticmethod
     def _convert_timestamp(timestamp):
         """Convert LabVIEW's timestamp to datetime
@@ -161,7 +173,7 @@ class TdmsObject:
 
 class Group(TdmsObject):
     """Group object for group properties and channel objects
-    
+
     Not intended to be instantiated in application code.
     """
 
@@ -169,14 +181,13 @@ class Group(TdmsObject):
         self._name = name
 
     def __iter__(self):
-        channels = [ch for ch in self.__dict__ if isinstance(self[ch], Channel)]
-        for ch in channels:
-            yield ch
+        for ch in self.channels:
+            yield self[ch]
 
     def __repr__(self):
         attributes = [key for key in self.__dict__ if not key.startswith("_")]
         attr_str = ", ".join(attributes)
-        repr_str = f"<TDMS_Group: {attr_str}>"
+        repr_str = f"<TDMS_Group {self._name}: {attr_str}>"
         if len(repr_str) > 50:
             midpt = len(repr_str) // 2
             repr_str = repr_str[0 : midpt - 1] + " ... " + repr_str[midpt + 2 :]
@@ -198,6 +209,16 @@ class Group(TdmsObject):
             lines.append(f"    {ch}")
         return "\n".join(lines)
 
+    @property
+    def channels(self):
+        """Channel names in group"""
+        return [ch for ch in self.__dict__ if isinstance(self[ch], Channel)]
+
+    @property
+    def name(self):
+        """Group name"""
+        return self._name
+
 
 class Channel(TdmsObject):
     """Channel object for channel properties and data
@@ -376,14 +397,14 @@ class Channel(TdmsObject):
                     values = struct.unpack(fmt, buf)
                     data.extend(values)
         data = np.asarray(data)
-        if uniform and data.size > n_values:
+        if uniform and data.size > n_values > 1:
             data = data.reshape(-1, n_values)
         return data
 
     def __repr__(self):
         attributes = [key for key in self.__dict__ if not key.startswith("_")]
         attr_str = ", ".join(attributes)
-        repr_str = f"<TDMS_Channel: {attr_str}>"
+        repr_str = f"<TDMS_Channel {self._name}: {attr_str}>"
         if len(repr_str) > 60:
             midpt = len(repr_str) // 2
             repr_str = repr_str[0 : midpt - 1] + " ... " + repr_str[midpt + 2 :]
@@ -397,3 +418,8 @@ class Channel(TdmsObject):
             lines.append(f"    {cp}")
         lines.append("    data")
         return "\n".join(lines)
+
+    @property
+    def name(self):
+        """Return name of channel"""
+        return self._name
